@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -39,7 +39,10 @@ void do_kcore_decomposition(GraphInterface& gi, boost::any prop)
         (gi.get_graph_view(), prop);
 }
 
-void export_kcore()
-{
-    python::def("kcore_decomposition", &do_kcore_decomposition);
-};
+#define __MOD__ topology
+#include "module_registry.hh"
+REGISTER_MOD
+([]
+ {
+     python::def("kcore_decomposition", &do_kcore_decomposition);
+ });
