@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -546,7 +546,7 @@ class NestedBlockState(object):
             if l > 0:
                 if "beta_dl" in entropy_args:
                     args = dict(args, beta=args.get("beta", 1.) * entropy_args["beta_dl"])
-                for p in ["B_max", "B_min", "b_max", "b_min"]:
+                for p in ["B_max", "B_min", "b_max", "b_min", "vertices"]:
                     args.pop(p, None)
 
             yield l, self.levels[l], args
@@ -789,7 +789,10 @@ class NestedBlockState(object):
         r"""Convenience wrapper to :func:`~graph_tool.draw.draw_hierarchy` that
         draws the hierarchical state."""
         import graph_tool.draw
-        return graph_tool.draw.draw_hierarchy(self, **kwargs)
+        return graph_tool.draw.draw_hierarchy(self,
+                                              vcmap=kwargs.pop("vcmap",
+                                                               graph_tool.draw.default_cm),
+                                              **kwargs)
 
 def get_hierarchy_tree(state, empty_branches=False):
     r"""Obtain the nested hierarchical levels as a tree.
